@@ -1,19 +1,18 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
-from functools import lru_cache, partial
+from functools import partial
 from operator import attrgetter
-from typing import TYPE_CHECKING, Any, Callable, Iterable, cast
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Literal, cast
 
 import rich.repr
 from rich.style import Style
 from typing_extensions import TypedDict
 
-from .._animator import DEFAULT_EASING, Animatable, BoundAnimator, EasingFunction
-from .._types import AnimationLevel, CallbackType
-from ..color import Color
-from ..geometry import Offset, Spacing
-from ._style_properties import (
+from textual._animator import DEFAULT_EASING, Animatable, BoundAnimator, EasingFunction
+from textual._types import AnimationLevel, CallbackType
+from textual.color import Color
+from textual.css._style_properties import (
     AlignProperty,
     BooleanProperty,
     BorderProperty,
@@ -38,7 +37,7 @@ from ._style_properties import (
     StyleFlagsProperty,
     TransitionsProperty,
 )
-from .constants import (
+from textual.css.constants import (
     VALID_ALIGN_HORIZONTAL,
     VALID_ALIGN_VERTICAL,
     VALID_BOX_SIZING,
@@ -50,10 +49,10 @@ from .constants import (
     VALID_TEXT_ALIGN,
     VALID_VISIBILITY,
 )
-from .scalar import Scalar, ScalarOffset, Unit
-from .scalar_animation import ScalarAnimation
-from .transition import Transition
-from .types import (
+from textual.css.scalar import Scalar, ScalarOffset, Unit
+from textual.css.scalar_animation import ScalarAnimation
+from textual.css.transition import Transition
+from textual.css.types import (
     AlignHorizontal,
     AlignVertical,
     BoxSizing,
@@ -67,11 +66,12 @@ from .types import (
     TextAlign,
     Visibility,
 )
+from textual.geometry import Offset, Spacing
 
 if TYPE_CHECKING:
-    from .._layout import Layout
-    from ..dom import DOMNode
-    from .types import CSSLocation
+    from textual._layout import Layout
+    from textual.css.types import CSSLocation
+    from textual.dom import DOMNode
 
 
 class RulesMap(TypedDict, total=False):
@@ -187,7 +187,7 @@ class RulesMap(TypedDict, total=False):
     border_subtitle_background: Color
     border_subtitle_style: Style
 
-    hatch: tuple[str, Color]
+    hatch: tuple[str, Color] | Literal["none"]
 
     overlay: Overlay
     constrain: Constrain
@@ -234,75 +234,165 @@ class StylesBase:
     display = StringEnumProperty(
         VALID_DISPLAY, "block", layout=True, refresh_parent=True, refresh_children=True
     )
+    """Set the display of the widget, defining how it's rendered.
+
+    Valid values are "block" or "none".
+    
+    "none" will hide and allow other widgets to fill the space that this widget would occupy.
+    
+    Set to None to clear any value that was set at runtime.
+
+    Raises:
+        StyleValueError: If an invalid display is specified.
+    """
+
     visibility = StringEnumProperty(
         VALID_VISIBILITY, "visible", layout=True, refresh_parent=True
     )
+    """Set the visibility of the widget.
+    
+    Valid values are "visible" or "hidden".
+
+    "hidden" will hide the widget, but reserve the space for this widget.
+    If you want to hide the widget and allow another widget to fill the space,
+    set the display attribute to "none" instead.
+    
+    Set to None to clear any value that was set at runtime.
+
+    Raises:
+        StyleValueError: If an invalid visibility is specified.
+    """
+
     layout = LayoutProperty()
+    """Set the layout of the widget, defining how it's children are laid out.
+    
+    Valid values are "grid", "horizontal", and "vertical" or None to clear any layout
+    that was set at runtime.
+
+    Raises:
+        MissingLayout: If an invalid layout is specified.
+    """
 
     auto_color = BooleanProperty(default=False)
     color = ColorProperty(Color(255, 255, 255))
+    """Set the foreground (text) color of the widget.
+    Supports `Color` objects but also strings e.g. "red" or "#ff0000".
+    You can also specify an opacity after a color e.g. "blue 10%"
+    """
     background = ColorProperty(Color(0, 0, 0, 0))
+    """Set the background color of the widget.
+    Supports `Color` objects but also strings e.g. "red" or "#ff0000"
+    You can also specify an opacity after a color e.g. "blue 10%"
+    """
     text_style = StyleFlagsProperty()
-
+    """Set the text style of the widget using Rich StyleFlags.
+    e.g. `"bold underline"` or `"b u strikethrough"`.
+    """
     opacity = FractionalProperty(children=True)
+    """Set the opacity of the widget, defining how it blends with the parent."""
     text_opacity = FractionalProperty()
-
+    """Set the opacity of the content within the widget against the widget's background."""
     padding = SpacingProperty()
+    """Set the padding (spacing between border and content) of the widget."""
     margin = SpacingProperty()
+    """Set the margin (spacing outside the border) of the widget."""
     offset = OffsetProperty()
-
+    """Set the offset of the widget relative to where it would have been otherwise."""
     border = BorderProperty(layout=True)
+    """Set the border of the widget e.g. ("rounded", "green") or "none"."""
+
     border_top = BoxProperty(Color(0, 255, 0))
+    """Set the top border of the widget e.g. ("rounded", "green") or "none"."""
     border_right = BoxProperty(Color(0, 255, 0))
+    """Set the right border of the widget e.g. ("rounded", "green") or "none"."""
     border_bottom = BoxProperty(Color(0, 255, 0))
+    """Set the bottom border of the widget e.g. ("rounded", "green") or "none"."""
     border_left = BoxProperty(Color(0, 255, 0))
+    """Set the left border of the widget e.g. ("rounded", "green") or "none"."""
 
     border_title_align = StringEnumProperty(VALID_ALIGN_HORIZONTAL, "left")
     border_subtitle_align = StringEnumProperty(VALID_ALIGN_HORIZONTAL, "right")
 
     outline = BorderProperty(layout=False)
+    """Set the outline of the widget e.g. ("rounded", "green") or "none".
+    The outline is drawn *on top* of the widget, rather than around it like border.
+    """
     outline_top = BoxProperty(Color(0, 255, 0))
+    """Set the top outline of the widget e.g. ("rounded", "green") or "none"."""
     outline_right = BoxProperty(Color(0, 255, 0))
+    """Set the right outline of the widget e.g. ("rounded", "green") or "none"."""
     outline_bottom = BoxProperty(Color(0, 255, 0))
+    """Set the bottom outline of the widget e.g. ("rounded", "green") or "none"."""
     outline_left = BoxProperty(Color(0, 255, 0))
+    """Set the left outline of the widget e.g. ("rounded", "green") or "none"."""
 
     keyline = KeylineProperty()
 
     box_sizing = StringEnumProperty(VALID_BOX_SIZING, "border-box", layout=True)
     width = ScalarProperty(percent_unit=Unit.WIDTH)
+    """Set the width of the widget."""
     height = ScalarProperty(percent_unit=Unit.HEIGHT)
+    """Set the height of the widget."""
     min_width = ScalarProperty(percent_unit=Unit.WIDTH, allow_auto=False)
+    """Set the minimum width of the widget."""
     min_height = ScalarProperty(percent_unit=Unit.HEIGHT, allow_auto=False)
+    """Set the minimum height of the widget."""
     max_width = ScalarProperty(percent_unit=Unit.WIDTH, allow_auto=False)
+    """Set the maximum width of the widget."""
     max_height = ScalarProperty(percent_unit=Unit.HEIGHT, allow_auto=False)
-
+    """Set the maximum height of the widget."""
     dock = DockProperty()
+    """Set which edge of the parent to dock this widget to e.g. "top", "left", "right", "bottom", "none".
+    """
     split = SplitProperty()
 
     overflow_x = OverflowProperty(VALID_OVERFLOW, "hidden")
+    """Control what happens when the content extends horizontally beyond the widget's width.
+
+    Valid values are "scroll", "hidden", or "auto".
+    """
+
     overflow_y = OverflowProperty(VALID_OVERFLOW, "hidden")
+    """Control what happens when the content extends vertically beyond the widget's height.
+
+    Valid values are "scroll", "hidden", or "auto".
+    """
 
     layer = NameProperty()
     layers = NameListProperty()
     transitions = TransitionsProperty()
 
     tint = ColorProperty("transparent")
+    """Set the tint of the widget. This allows you apply a opaque color above the widget.
+
+    You can specify an opacity after a color e.g. "blue 10%"
+    """
     scrollbar_color = ScrollbarColorProperty("ansi_bright_magenta")
+    """Set the color of the handle of the scrollbar."""
     scrollbar_color_hover = ScrollbarColorProperty("ansi_yellow")
+    """Set the color of the handle of the scrollbar when hovered."""
     scrollbar_color_active = ScrollbarColorProperty("ansi_bright_yellow")
-
+    """Set the color of the handle of the scrollbar when active (being dragged)."""
     scrollbar_corner_color = ScrollbarColorProperty("#666666")
-
+    """Set the color of the space between the horizontal and vertical scrollbars."""
     scrollbar_background = ScrollbarColorProperty("#555555")
+    """Set the background color of the scrollbar (the track that the handle sits on)."""
     scrollbar_background_hover = ScrollbarColorProperty("#444444")
+    """Set the background color of the scrollbar when hovered."""
     scrollbar_background_active = ScrollbarColorProperty("black")
+    """Set the background color of the scrollbar when active (being dragged)."""
 
     scrollbar_gutter = StringEnumProperty(
         VALID_SCROLLBAR_GUTTER, "auto", layout=True, refresh_children=True
     )
+    """Set to "stable" to reserve space for the scrollbar even when it's not visible.
+    This can prevent content from shifting when a scrollbar appears.
+    """
 
-    scrollbar_size_vertical = IntegerProperty(default=1, layout=True)
+    scrollbar_size_vertical = IntegerProperty(default=2, layout=True)
+    """Set the width of the vertical scrollbar (measured in cells)."""
     scrollbar_size_horizontal = IntegerProperty(default=1, layout=True)
+    """Set the height of the horizontal scrollbar (measured in cells)."""
 
     align_horizontal = StringEnumProperty(
         VALID_ALIGN_HORIZONTAL, "left", layout=True, refresh_children=True
@@ -354,6 +444,8 @@ class StylesBase:
     border_subtitle_style = StyleFlagsProperty()
 
     hatch = HatchProperty()
+    """Add a hatched background effect e.g. ("right", "yellow") or "none" to use no hatch.
+    """
 
     overlay = StringEnumProperty(
         VALID_OVERLAY, "none", layout=True, refresh_parent=True
@@ -385,7 +477,7 @@ class StylesBase:
             if not isinstance(value, (Scalar, ScalarOffset)):
                 return None
 
-            from ..widget import Widget
+            from textual.widget import Widget
 
             assert isinstance(self.node, Widget)
             return ScalarAnimation(
@@ -453,22 +545,34 @@ class StylesBase:
         height = self.height
         return height is not None and height.unit == Unit.AUTO
 
-    def has_rule(self, rule: str) -> bool:
+    @property
+    def is_docked(self) -> bool:
+        """Is the node docked?"""
+        dock = self.dock
+        return dock != "none"
+
+    @property
+    def is_split(self) -> bool:
+        """Is the node split?"""
+        split = self.split
+        return split != "none"
+
+    def has_rule(self, rule_name: str) -> bool:
         """Check if a rule is set on this Styles object.
 
         Args:
-            rule: Rule name.
+            rule_name: Rule name.
 
         Returns:
             ``True`` if the rules is present, otherwise ``False``.
         """
         raise NotImplementedError()
 
-    def clear_rule(self, rule: str) -> bool:
+    def clear_rule(self, rule_name: str) -> bool:
         """Removes the rule from the Styles object, as if it had never been set.
 
         Args:
-            rule: Rule name.
+            rule_name: Rule name.
 
         Returns:
             ``True`` if a rule was cleared, or ``False`` if the rule is already not set.
@@ -483,11 +587,11 @@ class StylesBase:
         """
         raise NotImplementedError()
 
-    def set_rule(self, rule: str, value: object | None) -> bool:
+    def set_rule(self, rule_name: str, value: object | None) -> bool:
         """Set a rule.
 
         Args:
-            rule: Rule name.
+            rule_name: Rule name.
             value: New rule value.
 
         Returns:
@@ -495,11 +599,11 @@ class StylesBase:
         """
         raise NotImplementedError()
 
-    def get_rule(self, rule: str, default: object = None) -> object:
+    def get_rule(self, rule_name: str, default: object = None) -> object:
         """Get an individual rule.
 
         Args:
-            rule: Name of rule.
+            rule_name: Name of rule.
             default: Default if rule does not exists.
 
         Returns:
@@ -554,7 +658,6 @@ class StylesBase:
         return rule in cls.ANIMATABLE
 
     @classmethod
-    @lru_cache(maxsize=1024)
     def parse(
         cls, css: str, read_from: CSSLocation, *, node: DOMNode | None = None
     ) -> Styles:
@@ -568,7 +671,7 @@ class StylesBase:
         Returns:
             A Styles instance containing result of parsing CSS.
         """
-        from .parse import parse_declarations
+        from textual.css.parse import parse_declarations
 
         styles = parse_declarations(css, read_from)
         styles.node = node
@@ -670,9 +773,7 @@ class StylesBase:
 @dataclass
 class Styles(StylesBase):
     node: DOMNode | None = None
-    _rules: RulesMap = field(
-        default_factory=RulesMap
-    )  # mypy won't be happy with `default_factory=RulesMap`
+    _rules: RulesMap = field(default_factory=RulesMap)
     _updates: int = 0
 
     important: set[str] = field(default_factory=set)
@@ -689,16 +790,16 @@ class Styles(StylesBase):
             important=self.important,
         )
 
-    def clear_rule(self, rule: str) -> bool:
+    def clear_rule(self, rule_name: str) -> bool:
         """Removes the rule from the Styles object, as if it had never been set.
 
         Args:
-            rule: Rule name.
+            rule_name: Rule name.
 
         Returns:
             ``True`` if a rule was cleared, or ``False`` if it was already not set.
         """
-        changed = self._rules.pop(rule, None) is not None  # type: ignore
+        changed = self._rules.pop(rule_name, None) is not None  # type: ignore
         if changed:
             self._updates += 1
         return changed
@@ -1220,18 +1321,20 @@ class RenderStyles(StylesBase):
         self._inline_styles.reset()
         self._updates += 1
 
-    def has_rule(self, rule: str) -> bool:
+    def has_rule(self, rule_name: str) -> bool:
         """Check if a rule has been set."""
-        return self._inline_styles.has_rule(rule) or self._base_styles.has_rule(rule)
+        return self._inline_styles.has_rule(rule_name) or self._base_styles.has_rule(
+            rule_name
+        )
 
-    def set_rule(self, rule: str, value: object | None) -> bool:
+    def set_rule(self, rule_name: str, value: object | None) -> bool:
         self._updates += 1
-        return self._inline_styles.set_rule(rule, value)
+        return self._inline_styles.set_rule(rule_name, value)
 
-    def get_rule(self, rule: str, default: object = None) -> object:
-        if self._inline_styles.has_rule(rule):
-            return self._inline_styles.get_rule(rule, default)
-        return self._base_styles.get_rule(rule, default)
+    def get_rule(self, rule_name: str, default: object = None) -> object:
+        if self._inline_styles.has_rule(rule_name):
+            return self._inline_styles.get_rule(rule_name, default)
+        return self._base_styles.get_rule(rule_name, default)
 
     def clear_rule(self, rule_name: str) -> bool:
         """Clear a rule (from inline)."""
